summaryrefslogtreecommitdiffstats
path: root/lib/kpilotdevicelink.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 00:37:32 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 00:37:32 +0000
commitf6f9c296c3f9d39a8c3d0ee64a542a47f450be28 (patch)
treed38fce8091ce66977004a5cb115768c7810aee30 /lib/kpilotdevicelink.h
parente340db64991a06761aa6395ffe760b53e4c1dfbc (diff)
downloadkpilot-f6f9c296c3f9d39a8c3d0ee64a542a47f450be28.tar.gz
kpilot-f6f9c296c3f9d39a8c3d0ee64a542a47f450be28.zip
TQt4 port kpilot
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpilot@1238903 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kpilotdevicelink.h')
-rw-r--r--lib/kpilotdevicelink.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/lib/kpilotdevicelink.h b/lib/kpilotdevicelink.h
index a648b23..b912c19 100644
--- a/lib/kpilotdevicelink.h
+++ b/lib/kpilotdevicelink.h
@@ -42,7 +42,7 @@ class DeviceCommThread; ///< Thread for doing all palm device communications
* it waits for the actual device to become available, and
* then becomes ready to handle syncing.
*/
-enum LinkStatus {
+enum LinktqStatus {
Init,
WaitingForDevice,
FoundDevice,
@@ -75,20 +75,21 @@ friend class PilotSerialDatabase;
friend class DeviceCommThread;
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor. Creates a link that can sync to a physical handheld.
* Call reset() on it to start looking for a device.
*
* @param parent Parent object.
* @param name Name of this object.
* @param tempDevice Path to device node to use as an alternative
* to the "normal" one set by KPilot.
*/
- KPilotDeviceLink( TQObject *parent = 0,
+ KPilotDeviceLink( TQObject *tqparent = 0,
const char *name = 0,
- const TQString &tempDevice = TQString::null );
+ const TQString &tempDevice = TQString() );
/**
* Destructor. This rudely ends the communication with the handheld.
@@ -99,15 +100,15 @@ public:
/**
* Get the status (state enum) of this link.
* @return The LinkStatus enum for the link's current state.
*/
- LinkStatus status() const
+ LinktqStatus status() const
{
- return fLinkStatus;
+ return fLinktqStatus;
}
/** Get a human-readable string for the given status @p l. */
- static TQString statusString(LinkStatus l);
+ static TQString statusString(LinktqStatus l);
// The following API is the actual implementation of
// the KPilotLink API, for documentation see that file.
@@ -140,7 +141,7 @@ protected:
private:
- LinkStatus fLinkStatus;
+ LinktqStatus fLinktqStatus;
public:
@@ -75,20 +75,21 @@ friend class PilotSerialDatabase;
* Call reset() on it to start looking for a device.
*
- * @param parent Parent object.
+ * @param tqparent Parent object.
* @param name Name of this object.
* @param tempDevice Path to device node to use as an alternative
@@ -99,15 +100,15 @@ public:
/**
* Get the status (state enum) of this link.
- * @return The LinkStatus enum for the link's current state.
+ * @return The LinktqStatus enum for the link's current state.
*/